@@ -31,7 +31,6 @@ testthat::test_that("module warns when server contains datasets argument", {
   )
 })
 
-
 testthat::test_that("module expects server being a shiny server module with any argument", {
   testthat::expect_no_error(module(server = function(id) NULL))
 
@@ -121,7 +120,10 @@ testthat::test_that("module() returns list of class 'teal_module' containing inp
     ui_args = NULL
   )
   testthat::expect_s3_class(test_module, "teal_module")
-  testthat::expect_named(test_module, c("label", "server", "ui", "datanames", "server_args", "ui_args"))
+  testthat::expect_named(
+    test_module,
+    c("label", "server", "ui", "datanames", "server_args", "ui_args", "transformators")
+  )
   testthat::expect_identical(test_module$label, "aaa1")
   testthat::expect_identical(test_module$server, call_module_server_fun)
   testthat::expect_identical(test_module$ui, ui_fun1)
@@ -507,8 +509,78 @@ testthat::test_that("format.teal_modules returns proper structure", {
 
   appended_mods <- append_module(mods, mod3)
 
-  testthat::expect_equal(
-    format(appended_mods),
-    "+ c\n + a\n + c\n + c\n"
+  testthat::expect_setequal(
+    strsplit(cli::ansi_strip(format(appended_mods)), "\n")[[1]],
+    c(
+      "TEAL ROOT",
+      "  |- a",
+      "  |  |- Datasets         : all",
+      "  |  |- Properties:",
+      "  |  |  |- Bookmarkable  : FALSE",
+      "  |  |  L- Reportable    : FALSE",
+      "  |  |- UI Arguments     : ",
+      "  |  |- Server Arguments : ",
+      "  |  |- Decorators       : ",
+      "  |  L- Transformators   : ",
+      "  |- c",
+      "  |  |- Datasets         : all",
+      "  |  |- Properties:",
+      "  |  |  |- Bookmarkable  : FALSE",
+      "  |  |  L- Reportable    : FALSE",
+      "  |  |- UI Arguments     : ",
+      "  |  |- Server Arguments : ",
+      "  |  |- Decorators       : ",
+      "  |  L- Transformators   : ",
+      "  L- c",
+      "     |- Datasets         : all",
+      "     |- Properties:",
+      "     |  |- Bookmarkable  : FALSE",
+      "     |  L- Reportable    : FALSE",
+      "     |- UI Arguments     : ",
+      "     |- Server Arguments : ",
+      "     |- Decorators       : ",
+      "     L- Transformators   : "
+    )
   )
 })
+
+
+testthat::test_that("module datanames is appended by its transformators datanames", {
+  transformator_w_datanames <- teal_transform_module(
+    ui = function(id) NULL,
+    server = function(id, data) {
+      moduleServer(id, function(input, output, session) {
+        reactive({
+          new_data <- within(data(), {
+            new_dataset <- data.frame(a = 1:3, b = 4:6)
+          })
+          new_data
+        })
+      })
+    },
+    datanames = c("a", "b")
+  )
+
+  out <- module(datanames = "c", transformators = list(transformator_w_datanames))
+  testthat::expect_identical(out$datanames, c("c", "a", "b"))
+})
+
+testthat::test_that("module datanames stays 'all' regardless of transformators", {
+  transformator_w_datanames <- teal_transform_module(
+    ui = function(id) NULL,
+    server = function(id, data) {
+      moduleServer(id, function(input, output, session) {
+        reactive({
+          new_data <- within(data(), {
+            new_dataset <- data.frame(a = 1:3, b = 4:6)
+          })
+          new_data
+        })
+      })
+    },
+    datanames = c("a", "b")
+  )
+
+  out <- module(datanames = "all", transformators = list(transformator_w_datanames))
+  testthat::expect_identical(out$datanames, "all")
+})
